<?php
namespace Estoque\Logic\AtualizacaoEstoque;

use \Estoque\Entities\Lanctoestoq;
use \Setforms2\Runtime\Helper\Procedure\Param;
use \Setforms2\Runtime\Helper\Procedure;

/**
 * Executa os calculos necessarios no processo de geracao da nota fiscal.
 *
 * Created by JetBrains PhpStorm.
 * User: paulopereira
 * Date: 29/10/12
 * Time: 14:51
 * To change this template use File | Settings | File Templates.
 */
class CalculaCustoLiquido
{

    /** @var $procedure Procedure */
    private static $procedure;


    /**
     * Executa a procedure de calculo do valor liquido da nota fiscal.
     *
     * @static
     * @param $cdfilial
     * @param $nrlanctoestq
     * @param $totalProd
     * @throws \Exception
     * @internal param \Estoque\Entities\Lanctoestoq $lanctoestoq
     */
    public static function CalcularCustoLiquido($cdfilial, $nrlanctoestq, $totalProd) {
        try {
            self::$procedure = new Procedure("CUSTO_LIQUIDO");
            self::adicionaParametrosCalculoCustoLiquido($cdfilial, $nrlanctoestq, $totalProd);
            self::$procedure->call();
        } catch (\Exception $e) {
            throw $e;
        }
    }

    /**
     * Inicializa os parametros da procedure de CalcularCustoLiquido.
     *
     * @static
     * @param $cdfilial
     * @param $nrlanctoestq
     * @param $totalProd
     * @internal param \Estoque\Entities\Lanctoestoq $lanctoestoq
     */
    protected static function adicionaParametrosCalculoCustoLiquido($cdfilial, $nrlanctoestq, $totalProd)
    {

        self::$procedure->addParam(
            new Param(
                "P_FILIAL",
                Param::PARAM_INPUT,
                $cdfilial,
                Param::PARAM_TYPE_STR
            )
        );
        self::$procedure->addParam(
            new Param(
                "P_LANCTO",
                Param::PARAM_INPUT,
                $nrlanctoestq,
                Param::PARAM_TYPE_STR
            )
        );
        self::$procedure->addParam (
            new Param(
                "TOTALPROD",
                Param::PARAM_INPUT,
                $totalProd,
                Param::PARAM_TYPE_INT
            )
        );
        self::$procedure->addParam(
            new Param(
                "P_DIFERENCA",
                Param::PARAM_INPUT,
                null,
                Param::PARAM_TYPE_STR
            )
        );
        self::$procedure->addParam(
            new Param(
                "P_GRAVVRBRUT",
                Param::PARAM_INPUT,
                "N",
                Param::PARAM_TYPE_STR
            )
        );
    }

}
